@@ -29,7 +29,7 @@ import geopandas as gpd
 # Working with Online Services
 ##############################
 
-# Working with Web Mas Services
+# Working with Web Map Services
 ###############################
 
 
@@ -482,7 +482,7 @@ def load_as_array(url: str,
 
 
 def load_wfs(url: str):  # -> owslib.wfs.WebFeatureService:
-    """Loading an WMS Service by URL
+    """Loading a WFS Service by URL
 
     Parameters
     __________
